/*
 *  Copyright (C) Chaperon. All rights reserved.                               
 *  ------------------------------------------------------------------------- 
 *  This software is published under the terms of the Apache Software License 
 *  version 1.1, a copy of which has been included  with this distribution in 
 *  the LICENSE file.                                                         
 */

package net.sourceforge.chaperon.grammar.token.definition;

import java.io.Serializable;

import net.sourceforge.chaperon.grammar.Grammar;
import net.sourceforge.chaperon.helpers.Decoder;
import net.sourceforge.chaperon.helpers.IntegerList;
import net.sourceforge.chaperon.parser.RegexAutomate;

/**
 * This class represents a sequence of characters, like a string
 *
 * @author Stephan Michels
 * @version $Revision: 1.2 $ $Date: 2002/05/06 16:22:56 $
 */
public class CharacterSequence extends DefinitionElement implements Serializable, Cloneable
{

  private String _sequence = "";

  /**
   * Creates a character sequence
   */
  public CharacterSequence()
  {
  }

  /**
   * Creates a character sequence
   *
   * @param sequence Seqence of characaters
   */
  public CharacterSequence(String sequence)
  {
    setSequence(sequence);
  }

  /**
   * Set the sequence of characters
   *
   * @param sequence Seqence of characaters
   */
  public void setSequence(String sequence)
  {
    _sequence = sequence;
  }

  /**
   * Returns the sequence of characters
   *
   * @return Seqence of characaters
   */
  public String getSequence()
  {
    return _sequence;
  }

  /**
   * Convert the character sequence to a string
   *
   * @return Content of the sequence
   */
  public String toString()
  {
    return Decoder.decode(_sequence);
  }

  public Object clone() throws CloneNotSupportedException
  { 
    CharacterSequence clone = new CharacterSequence();
    
    clone.setMinOccurs(getMinOccurs());
    clone.setMaxOccurs(getMaxOccurs());

    clone.setSequence(getSequence());
    
    return clone;
  }
}
